@@ -20,9 +20,10 @@ Login provides user with language selection
 """
 import logging
 
-from urwid import (ListBox, Pile, Text)
+from urwid import Text
 
 from subiquitycore.ui.buttons import finish_btn
+from subiquitycore.ui.container import ListBox, Pile
 from subiquitycore.ui.utils import Padding, Color
 from subiquitycore.view import BaseView
 
@@ -45,8 +46,7 @@ class LoginView(BaseView):
 
     def _build_buttons(self):
         self.buttons = [
-            Color.button(finish_btn(on_press=self.done),
-                         focus_map='button focus'),
+            Color.button(finish_btn(on_press=self.done)),
         ]
         return Pile(self.buttons)
 
@@ -70,7 +70,7 @@ class LoginView(BaseView):
         login_text += remote_tpl.format(**login_info)
         ips = []
         for dev in self.netdevs:
-            for addr in dev.actual_ip_addresses:
+            for addr in dev.actual_global_ip_addresses:
                 ips.append(addr)
 
         sl += [Text(login_text), Padding.line_break("")]
@@ -78,15 +78,6 @@ class LoginView(BaseView):
             ssh_iface = "    ssh %s@%s" % (user.username, ip)
             sl.append(Text(ssh_iface))
 
-        sl += [
-            Padding.line_break(""),
-            Text("SSH keys with the following fingerprints can be used to log in:"),
-            Padding.line_break(""),
-        ]
-
-        for fingerprint in user.fingerprints:
-            sl.append(Text("    " + fingerprint))
-
         return Pile(sl)
 
     def confirm(self, result):
