@@ -15,9 +15,9 @@
 
 from subiquitycore.controllers.login import LoginController  # NOQA
 from subiquitycore.controllers.network import NetworkController  # NOQA
-from subiquitycore.controllers.welcome import WelcomeController  # NOQA
 
 from .identity import IdentityController  # NOQA
 from .installpath import InstallpathController  # NOQA
 from .installprogress import InstallProgressController  # NOQA
 from .filesystem import FilesystemController  # NOQA
+from .welcome import WelcomeController  # NOQA
