@@ -14,10 +14,11 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
-from urwid import Text, Columns, Pile, ListBox
+from urwid import Text
 
 from subiquitycore.view import BaseView
 from subiquitycore.ui.buttons import cancel_btn, done_btn
+from subiquitycore.ui.container import Columns, ListBox, Pile
 from subiquitycore.ui.interactive import StringEditor
 from subiquitycore.ui.utils import Color, Padding
 
@@ -28,9 +29,9 @@ class CephDiskView(BaseView):
     def __init__(self, model, signal):
         self.model = model
         self.signal = signal
-        self.ceph_mon = StringEditor(caption="")
-        self.username = StringEditor(caption="")
-        self.ceph_key = StringEditor(caption="")
+        self.ceph_mon = StringEditor()
+        self.username = StringEditor()
+        self.ceph_key = StringEditor()
         self.pool = []
         body = [
             Padding.center_50(self._build_model_inputs()),
@@ -44,9 +45,7 @@ class CephDiskView(BaseView):
             Columns(
                 [
                     ("weight", 0.2, Text("Ceph MON", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.ceph_mon,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.ceph_mon))
                 ],
                 dividechars=4
             ),
@@ -54,18 +53,14 @@ class CephDiskView(BaseView):
                 [
                     ("weight", 0.2, Text("Username",
                                          align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.username,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.username))
                 ],
                 dividechars=4
             ),
             Columns(
                 [
                     ("weight", 0.2, Text("Key", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.ceph_key,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.ceph_key))
                 ],
                 dividechars=4
             )
@@ -77,8 +72,8 @@ class CephDiskView(BaseView):
         done = done_btn(on_press=self.done)
 
         buttons = [
-            Color.button(done, focus_map='button focus'),
-            Color.button(cancel, focus_map='button focus')
+            Color.button(done),
+            Color.button(cancel)
         ]
         return Pile(buttons)
 
