@@ -20,12 +20,12 @@ configuration.
 
 """
 import logging
+import os
 import re
 from urwid import connect_signal, Text
 
 from subiquitycore.ui.container import Columns, ListBox
 from subiquitycore.ui.form import (
-    BoundFormField,
     Form,
     FormField,
     IntegerField,
@@ -40,7 +40,7 @@ from subiquity.models.filesystem import (
     _dehumanize_size,
     HUMAN_UNITS,
     )
-from subiquity.ui.mount import MountSelector
+from subiquity.ui.mount import MountField
 
 
 log = logging.getLogger('subiquity.ui.filesystem.add_partition')
@@ -51,20 +51,19 @@ class FSTypeField(FormField):
         return Selector(opts=form.model.supported_filesystems)
 
 
-class MountField(FormField):
-    def _make_widget(self, form):
-        return MountSelector(form.model)
-
-
 class AddPartitionForm(Form):
 
-    def __init__(self, model, disk_obj):
+    def __init__(self, model, disk):
         self.model = model
-        self.disk_obj = disk_obj
-        self.size_str = _humanize_size(disk_obj.freespace)
+        self.disk = disk
+        self.size_str = _humanize_size(disk.free)
         super().__init__()
         self.size.caption = "Size (max {})".format(self.size_str)
-        self.partnum.value = str(self.disk_obj.lastpartnumber + 1)
+        self.partnum.value = self.disk.next_partnum
+        connect_signal(self.fstype.widget, 'select', self.select_fstype)
+
+    def select_fstype(self, sender, fs):
+        self.mount.enabled = fs.is_mounted
 
     partnum = IntegerField("Partition number")
     size = StringField()
@@ -85,40 +84,29 @@ class AddPartitionForm(Form):
             v += unit
             self.size.value = v
         sz = _dehumanize_size(v)
-        if sz > self.disk_obj.freespace:
+        if sz > self.disk.free:
             self.size.value = self.size_str
             self.size.show_extra(Color.info_minor(Text("Capped partition size at %s"%(self.size_str,), align="center")))
 
     def validate_mount(self):
-        mnts = self.model.get_mounts2()
-        dev = mnts.get(self.mount.value)
-        if dev is not None:
-            return "%s is already mounted at %s"%(dev, self.mount.value)
+        return self.model.validate_mount(self.mount.value)
 
 
 class AddPartitionView(BaseView):
 
-    def __init__(self, model, controller, selected_disk):
-        log.debug('AddPartitionView: selected_disk=[{}]'.format(selected_disk))
+    def __init__(self, model, controller, disk):
+        log.debug('AddPartitionView: selected_disk=[{}]'.format(disk.path))
         self.model = model
         self.controller = controller
-        self.selected_disk = selected_disk
-        self.disk_obj = self.model.get_disk(selected_disk)
+        self.disk = disk
 
-        self.form = AddPartitionForm(model, self.disk_obj)
+        self.form = AddPartitionForm(model, self.disk)
 
         connect_signal(self.form, 'submit', self.done)
         connect_signal(self.form, 'cancel', self.cancel)
-        connect_signal(self.form.fstype.widget, 'select', self.select_fstype)
 
         body = [
-            Columns(
-                [
-                    ("weight", 0.2, Text("Adding partition to {}".format(
-                        self.disk_obj.devpath), align="right")),
-                    ("weight", 0.3, Text(""))
-                ]
-            ),
+            Text("Adding partition to {}".format(self.disk.path), align="center"),
             Padding.line_break(""),
             self.form.as_rows(self),
             Padding.line_break(""),
@@ -127,9 +115,6 @@ class AddPartitionView(BaseView):
         partition_box = Padding.center_50(ListBox(body))
         super().__init__(partition_box)
 
-    def select_fstype(self, sender, fs):
-        self.form.mount.enabled = fs.is_mounted
-
     def cancel(self, button):
         self.controller.prev_view()
 
@@ -144,10 +129,10 @@ class AddPartitionView(BaseView):
 
         if self.form.size.value:
             size = _dehumanize_size(self.form.size.value)
-            if size > self.disk_obj.freespace:
-                size = self.disk_obj.freespace
+            if size > self.disk.free:
+                size = self.disk.free
         else:
-            size = self.disk_obj.freespace
+            size = self.disk.free
 
         result = {
             "partnum": self.form.partnum.value,
@@ -158,4 +143,4 @@ class AddPartitionView(BaseView):
         }
 
         log.debug("Add Partition Result: {}".format(result))
-        self.controller.add_disk_partition_handler(self.disk_obj.devpath, result)
+        self.controller.add_disk_partition_handler(self.disk, result)
