@@ -19,11 +19,12 @@ Provides high level options for Ubuntu install
 
 """
 import logging
-from urwid import (ListBox, Pile, BoxAdapter)
+from urwid import BoxAdapter
 
 from subiquitycore.ui.lists import SimpleList
 from subiquitycore.ui.buttons import menu_btn, cancel_btn
 from subiquitycore.ui.utils import Padding, Color
+from subiquitycore.ui.container import ListBox, Pile
 from subiquitycore.view import BaseView
 
 log = logging.getLogger('subiquity.installpath')
@@ -43,8 +44,7 @@ class InstallpathView(BaseView):
 
     def _build_buttons(self):
         self.buttons = [
-            Color.button(cancel_btn(on_press=self.cancel),
-                         focus_map='button focus'),
+            Color.button(cancel_btn(on_press=self.cancel)),
         ]
         return Pile(self.buttons)
 
@@ -55,8 +55,7 @@ class InstallpathView(BaseView):
             sl.append(Color.menu_button(
                 menu_btn(label=ipath,
                          on_press=self.confirm,
-                         user_data=sig),
-                focus_map='menu_button focus'))
+                         user_data=sig)))
 
         return BoxAdapter(SimpleList(sl),
                           height=len(sl))
