@@ -14,10 +14,11 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import logging
-from urwid import Text, Columns, Pile, ListBox
+from urwid import Text
 
 from subiquitycore.view import BaseView
 from subiquitycore.ui.buttons import menu_btn
+from subiquitycore.ui.container import Columns, ListBox, Pile
 from subiquitycore.ui.interactive import (StringEditor, YesNo,
                                           PasswordEditor)
 from subiquitycore.ui.utils import Color, Padding
@@ -29,13 +30,13 @@ class IscsiDiskView(BaseView):
     def __init__(self, model, signal):
         self.model = model
         self.signal = signal
-        self.iscsi_host = StringEditor(caption="")
+        self.iscsi_host = StringEditor()
         self.connect_anon = YesNo()
-        self.connect_username = StringEditor(caption="")
-        self.connect_password = PasswordEditor(caption="")
+        self.connect_username = StringEditor()
+        self.connect_password = PasswordEditor()
         self.server_auth = YesNo()
-        self.server_username = StringEditor(caption="")
-        self.server_password = PasswordEditor(caption="")
+        self.server_username = StringEditor()
+        self.server_password = PasswordEditor()
         body = [
             Padding.center_50(self._build_model_inputs()),
             Padding.line_break(""),
@@ -50,65 +51,49 @@ class IscsiDiskView(BaseView):
             Columns(
                 [
                     ("weight", 0.2, Text("iSCSI Server Host", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.iscsi_host,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.iscsi_host))
                 ],
                 dividechars=4
             ),
             Columns(
                 [
-                    ("weight", 0.2, Text("Connect anonymously",
-                                         align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(Pile(self.connect_anon.group),
-                                        focus_map="string_input focus"))
+                    ("weight", 0.2, Text("Connect anonymously", align="right")),
+                    ("weight", 0.3, Color.string_input(Pile(self.connect_anon.group)))
                 ],
                 dividechars=4
             ),
             Columns(
                 [
                     ("weight", 0.2, Text("Connect as user", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.connect_username,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.connect_username))
                 ],
                 dividechars=4
             ),
             Columns(
                 [
                     ("weight", 0.2, Text("Password", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.connect_password,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.connect_password))
                 ],
                 dividechars=4
             ),
             Columns(
                 [
-                    ("weight", 0.2, Text("Require server auth",
-                                         align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(Pile(self.server_auth.group),
-                                        focus_map="string_input focus"))
+                    ("weight", 0.2, Text("Require server auth", align="right")),
+                    ("weight", 0.3, Color.string_input(Pile(self.server_auth.group)))
                 ],
                 dividechars=4
             ),
             Columns(
                 [
                     ("weight", 0.2, Text("Server identity", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.server_username,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.server_username))
                 ],
                 dividechars=4
             ),
             Columns(
                 [
                     ("weight", 0.2, Text("Server password", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(self.server_password,
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.server_password))
                 ],
                 dividechars=4
             )
@@ -126,8 +111,7 @@ class IscsiDiskView(BaseView):
                          Color.menu_button(
                              menu_btn(label=label,
                                       on_press=self.confirm,
-                                      user_data=sig),
-                             focus_map="menu_button focus"))
+                                      user_data=sig)))
                     ]))
         return Pile(items)
 
