@@ -23,7 +23,6 @@ from socket import AF_INET, AF_INET6
 
 import yaml, yaml.reader
 
-from subiquitycore.model import BaseModel
 
 NETDEV_IGNORED_IFACE_NAMES = ['lo']
 NETDEV_IGNORED_IFACE_TYPES = ['bridge', 'tun', 'tap', 'dummy', 'sit']
@@ -126,6 +125,12 @@ class Networkdev:
         else:
             return {}
 
+    @property
+    def configured(self):
+        if self.configured_ip_addresses or self.dhcp4 or self.dhcp6:
+            return True
+        return False
+
     @property
     def name(self):
         return self._net_info.name
@@ -213,7 +218,7 @@ class Networkdev:
             fam = AF_INET
         elif version == 6:
             fam = AF_INET6
-        return [ipaddress.ip_interface(a).ip for a in self._net_info.ip.get(fam, [])]
+        return [addr.ip for _, addr in sorted(self._net_info.addresses.items()) if addr.family == fam]
 
     @property
     def actual_ip_addresses(self):
@@ -226,6 +231,10 @@ class Networkdev:
                 r.append(ip)
         return r
 
+    @property
+    def actual_global_ip_addresses(self):
+        return [addr.ip for _, addr in sorted(self._net_info.addresses.items()) if addr.scope == "global"]
+
     @property
     def configured_ip_addresses(self):
         return self._configuration.setdefault('addresses', [])
@@ -332,7 +341,7 @@ def valid_ipv4_address(addr):
     return ip
 
 
-class NetworkModel(BaseModel):
+class NetworkModel(object):
     """ Model representing network interfaces
     """
 
@@ -419,6 +428,9 @@ class NetworkModel(BaseModel):
     def get_all_netdevs(self):
         return [v for k, v in sorted(self.devices_by_name.items())]
 
+    def get_configured_interfaces(self):
+        return [dev for dev in self.get_all_netdevs() if dev.configured]
+
     def get_netdev_by_name(self, name):
         return self.devices_by_name[name]
 
