@@ -13,9 +13,10 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from urwid import Text, Columns, Pile, ListBox, CheckBox
+from urwid import Text, CheckBox
 from subiquitycore.view import BaseView
 from subiquitycore.ui.buttons import cancel_btn, done_btn
+from subiquitycore.ui.container import Columns, ListBox, Pile
 from subiquitycore.ui.interactive import Selector
 from subiquitycore.ui.utils import Color, Padding
 import logging
@@ -73,9 +74,7 @@ class NetworkBondInterfacesView(BaseView):
             Columns(
                 [
                     ("weight", 0.2, Text("Bonding Mode", align="right")),
-                    ("weight", 0.3,
-                     Color.string_input(Pile(self.bond_mode.group),
-                                        focus_map="string_input focus"))
+                    ("weight", 0.3, Color.string_input(self.bond_mode))
                 ],
                 dividechars=4
             ),
@@ -89,8 +88,8 @@ class NetworkBondInterfacesView(BaseView):
         done = done_btn(on_press=self.done)
 
         items = [
-            Color.button(done, focus_map='button focus'),
-            Color.button(cancel, focus_map='button focus')
+            Color.button(done),
+            Color.button(cancel)
         ]
         log.debug('buttons: items: {}'.format(items))
         return Pile(items)
