@@ -1,8 +1,15 @@
-from urwid import Text, Overlay, WidgetWrap, LineBox, Button, BoxAdapter
+from urwid import (
+    BoxAdapter,
+    Button,
+    connect_signal,
+    LineBox,
+    Text,
+    WidgetWrap,
+    )
 from subiquitycore.view import BaseView
-from subiquitycore.ui.buttons import cancel_btn, done_btn, menu_btn
+from subiquitycore.ui.buttons import cancel_btn, menu_btn
 from subiquitycore.ui.container import Columns, ListBox, Pile
-from subiquitycore.ui.interactive import PasswordEditor, StringEditor
+from subiquitycore.ui.form import Form, PasswordField, StringField
 from subiquitycore.ui.utils import Color, Padding
 import logging
 
@@ -22,32 +29,55 @@ class NetworkList(WidgetWrap):
         super().__init__(box)
 
     def do_network(self, sender):
-        self.parent.ssid_input.value = sender.label
+        self.parent.form.ssid.value = sender.label
         self.parent.remove_overlay()
 
     def do_cancel(self, sender):
         self.parent.remove_overlay()
 
 
+class WLANForm(Form):
+
+    ssid = StringField(caption="Network Name:")
+    psk = PasswordField(caption="Password:")
+
+    def validate_psk(self):
+        psk = self.psk.value
+        if len(psk) == 0:
+            return
+        elif len(psk) < 8:
+            return "Password must be at least 8 characters long if present"
+        elif len(psk) > 63:
+            return "Password must be less than 63 characters long"
+
 class NetworkConfigureWLANView(BaseView):
     def __init__(self, model, controller, name):
         self.model = model
         self.controller = controller
         self.dev = self.model.get_netdev_by_name(name)
-        self.ssid_input = StringEditor()
+
+        self.form = WLANForm()
+
+        connect_signal(self.form, 'submit', self.done)
+        connect_signal(self.form, 'cancel', self.cancel)
+
         if self.dev.configured_ssid is not None:
-            self.ssid_input.value = self.dev.configured_ssid
-        self.psk_input = PasswordEditor()
+            self.form.ssid.value = self.dev.configured_ssid
         if self.dev.configured_wifi_psk is not None:
-            self.psk_input.value = self.dev.configured_wifi_psk
+            self.form.psk.value = self.dev.configured_wifi_psk
+
+        self.ssid_row = self.form.ssid.as_row(self, self.form.longest_caption)
+        self.psk_row = self.form.psk.as_row(self, self.form.longest_caption)
+
         self.inputs = Pile(self._build_iface_inputs())
+
         self.error = Text("")
         self.body = [
             Padding.center_79(self.inputs),
             Padding.line_break(""),
             Padding.center_79(Color.info_error(self.error)),
             Padding.line_break(""),
-            Padding.fixed_10(self._build_buttons())
+            Padding.fixed_10(Pile([self.form.done_btn, self.form.cancel_btn])),
         ]
         self.orig_w = None
         super().__init__(ListBox(self.body))
@@ -81,6 +111,7 @@ class NetworkConfigureWLANView(BaseView):
                     Text("No visible networks"),
                     ('fixed', 1, Text(">"))
                 ], dividechars=1))
+
         if not self.dev.scan_state:
             scan_btn = Color.menu_button(
                 menu_btn("Scan for networks", on_press=self.start_scan))
@@ -95,31 +126,10 @@ class NetworkConfigureWLANView(BaseView):
         col = [
             Padding.center_79(Color.info_minor(Text("Only open or WPA2/PSK networks are supported at this time."))),
             Padding.line_break(""),
-            Columns(
-                [
-                    ("weight", 0.2, Text("Network name:")),
-                    ("weight", 0.3, Color.string_input(self.ssid_input)),
-                ], dividechars=2
-            ),
-            Columns(
-                [
-                    ("weight", 1.0,
-                     Padding.fixed_30(networks_btn)),
-                ]
-            ),
-            Columns(
-                [
-                    ("weight", 1.0,
-                     Padding.fixed_30(scan_btn)),
-                ]
-            ),
-            Columns(
-                [
-                    ("weight", 0.2, Text("Password:")),
-                    ("weight", 0.3,
-                     Color.string_input(self.psk_input)),
-                ], dividechars=2
-            ),
+            self.ssid_row,
+            Padding.fixed_30(networks_btn),
+            Padding.fixed_30(scan_btn),
+            self.psk_row,
         ]
         return col
 
@@ -133,27 +143,20 @@ class NetworkConfigureWLANView(BaseView):
             return
         self.inputs.contents = [ (obj, ('pack', None)) for obj in self._build_iface_inputs() ]
 
-    def _build_buttons(self):
-        cancel = Color.button(cancel_btn(on_press=self.cancel))
-        done = Color.button(done_btn(on_press=self.done))
-
-        buttons = [done, cancel]
-        return Pile(buttons, focus_item=done)
-
-    def done(self, btn):
-        if self.dev.configured_ssid is None and self.ssid_input.value:
+    def done(self, sender):
+        if self.dev.configured_ssid is None and self.form.ssid.value:
             # Turn DHCP4 on by default when specifying an SSID for the first time...
             self.dev.dhcp4 = True
-        if self.ssid_input.value:
-            ssid = self.ssid_input.value
+        if self.form.ssid.value:
+            ssid = self.form.ssid.value
         else:
             ssid = None
-        if self.psk_input.value:
-            psk = self.psk_input.value
+        if self.form.psk.value:
+            psk = self.form.psk.value
         else:
             psk = None
         self.dev.set_ssid_psk(ssid, psk)
         self.controller.prev_view()
 
-    def cancel(self, btn):
+    def cancel(self, sender):
         self.controller.prev_view()
